<template>
  <div class="BarMonitorEcharts">
    <div class="ClassItem">
      <div class="ClassStatistics">
        <div class="ClassProportion">
          <echarts chart-id="BarMonitorEcharts" :chart-option="options" v-if="isShow"></echarts>
          <!-- <el-empty :image="imgSrc" :image-size="80" description="暂无数据" v-else></el-empty> -->
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
export default {
  name: 'BarMonitorEcharts',
  props: {
    dataObj: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      isShow: true,
      options: {
        title: {},
        // backgroundColor: '#232d36',
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            lineStyle: {
              color: {
                type: 'linear',
                x: 0,
                y: 0,
                x2: 0,
                y2: 1,
                colorStops: [{
                  offset: 0,
                  color: 'rgba(0, 255, 233,0)'
                }, {
                  offset: 0.5,
                  color: 'rgba(255, 255, 255,1)'
                }, {
                  offset: 1,
                  color: 'rgba(0, 255, 233,0)'
                }],
                global: false
              }
            }
          },
          extraCssText: 'background: #fff; border-radius: 0;box-shadow: 0 0 3px rgba(0, 0, 0, 0.2);color: #333;'
        },
        legend: [
          {
            show:true,
            data: ['在线数'],
            top: '7%',
            left: '43%',
            textStyle: {
              fontSize: 12,
              fontFamily: 'Alimama ShuHeiTi',
              fontWeight: 'bold',
              color: '#F8FCFF',
              opacity: 0.6
            },
            // icon: 'image://' + require('@/assets/img/riskMonitor/integrated/rightCons/legend1.png'),
            icon: 'roundRect',
            itemWidth: 30,
            itemHeight: 14
          },
        ],
        grid: {
          top: '20%',
          left: '10%',
          right: '3%',
          bottom: '25%'
          // containLabel: true
        },
        xAxis: [{
          type: 'category',
          axisLine: {
            show: true,
            lineStyle: {
              color: '#818181', // x轴的颜色
              width: 1 // 轴线的宽度
            }
          },
          axisLabel: {
            fontSize: '12px',
            fontFamily: 'Alimama ShuHeiTi',
            fontWeight: 'bold',
            color: '#FFFFFF',
            opacity: 0.6,
            interval: 0,  // 设置间隔为0
            // 此为关键点
            formatter: function (params) {
            // params为x轴文字内容
              var newParamsName = "";
              var paramsNameNumber = params.length;
              var provideNumber = 1; //一行显示几个字
              var rowNumber = Math.ceil(paramsNameNumber / provideNumber);
              if (paramsNameNumber > provideNumber) {
                for (var p = 0; p < rowNumber; p++) {
                  var tempStr = "";
                  var start = p * provideNumber;
                  var end = start + provideNumber;
                  if (p == rowNumber - 1) {
                    tempStr = params.substring(start, paramsNameNumber);
                  } else {
                    tempStr = params.substring(start, end) + "\n";
                  }
                  newParamsName += tempStr;
                }
              } else {
                newParamsName = params;
              }
              return newParamsName;
            }
          },
          splitLine: {
            show: false,
            lineStyle: {
              color: '#00BFF3',
              opacity: 0.23,
              type: 'dashed'
            }
          },
          boundaryGap: true,
          splitArea: {
            show: false,
            interval: 0,
            areaStyle: {
              color: ['rgba(30,47,66,0.35)', 'rgba(200,200,200,0)']
              // color: ['rgba(30,47,66,0.35)'], // 这里重点，用于设置颜色的数组，
              //（有了这个属性，那我们完全可以自己在根据某些条件来生成这样一个数组）
              // shadowColor: 'rgba(0, 0, 0, 0)',
              // shadowBlur: 0,
              // shadowOffsetX: 0,
              // shadowOffsetY: 0
            }
          },
          data: ['2022-02', '2022-04', '2022-06', '2022-08', '2022-10', '2022-12', '2023-02']
        }],
        yAxis: [{
          name: '',
          type: 'value',
          min: 0,
          // max: 140,
          splitNumber: 4,
          splitLine: {
            show: true,
            lineStyle: {
              color: '#ffffff',
              opacity: 0.2,
              type: 'dashed'
            }
          },
          nameTextStyle: {
            fontSize: '12px',
            fontFamily: 'Alimama ShuHeiTi',
            fontWeight: 'bold',
            color: '#FFFFFF',
            opacity: 0.6
          },
          axisLine: {
            show: false
          },
          axisLabel: {
            opacity: 0.6,
            show: true,
            // margin: 14,
            textStyle: {
              fontSize: '12px',
              fontFamily: 'Alimama ShuHeiTi',
              fontWeight: 'bold',
              color: '#FFFFFF'
            },
            formatter: (value) => {
              if (value >= 10000) {
                value = (value / 10000) + 'W'
              }
              if (value >= 1000) {
                value = (value / 1000) + 'K'
              }
              return value
            }
          },
          axisTick: {
            show: false
          }
        }],
        series: [
          {
            name: '在线数',
            type: 'bar',
            barWidth: '25%',
            barGap: '80%',
            itemStyle: {
              normal: {
                color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [{
                  offset: 1,
                  color: 'rgba(0,199,255,0.02)'
                },
                {
                  offset: 0.6,
                  color: 'rgba(113,213,241,0.68)'
                },
                {
                  offset: 0,
                  color: 'rgba(0,198,255,1)'
                }]),
                barBorderRadius: [8, 8, 0, 0]
              }
            },
            data: [3, 5, 4, 2, 1, 7, 6]
          }
        ]
      }
    }
  },
  created() {
  },
  mounted() {
    this.$nextTick(() => {
      this.initChart(this.dataObj)
    })
  },
  watch: {
    dataObj(nV) {
      // console.log(nV)
      this.initChart(nV)
    }
  },
  methods: {
    initChart(data) {
      this.options.xAxis[0].data = []
      this.options.series[0].data = []
      // if () {
      //   this.options.title = {
      //     text: '暂无数据~~',
      //     x: 'center',
      //     y: 'center',
      //     textStyle: {
      //       fontSize: 12,
      //       fontWeight: 'normal'
      //     }
      //   }
      // }
      this.options.xAxis[0].data = data.alarmFirst.xData
      this.options.series[0].data = data.alarmFirst.yData
    }
  }
}

</script>

<style lang="scss" scoped>
.BarMonitorEcharts{
  position: absolute;
  top: 0;
  width: 100%;
  height: 100%;
  .ClassItem{
    position: relative;
    height: 100%;
    box-sizing: border-box;
    .ClassStatistics {
      display: flex;
      align-items: center;
      height: 100%;
      .ClassProportion {
        overflow: hidden;
        width: 100%;
        height: 100%;
        #BarMonitorEcharts{
          width: 100%;
          height: 100%;
        }
      }
    }
  }
}
</style>
